==> hyperlog-0.0.2-sources.jar: com/hypertrack/hyperlog/HyperLogCallback.java <==

/*
The MIT License (MIT)

Copyright (c) 2015-2017 HyperTrack (http://hypertrack.com)

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
*/
package com.hypertrack.hyperlog;

import android.support.annotation.NonNull;

import com.android.volley.VolleyError;

/**
 * Created by Aman Jain on 18/09/17.
 */
public abstract class HyperLogCallback {

    /**
     * Called when a request succeeds.
     *
     * @param response The successful response containing the responseObject.
     */
    public abstract void onSuccess(@NonNull String response);

    /**
     * Called when a validation error occurs, request times out, or fails.
     *
     * @param errorResponse The request status.
     */
    public abstract void onError(@NonNull VolleyError errorResponse);
}

==> hyperlog-0.0.5-sources.jar: com/hypertrack/hyperlog/HyperLogCallback.java <==

/*
The MIT License (MIT)

Copyright (c) 2015-2017 HyperTrack (http://hypertrack.com)

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
*/
package com.hypertrack.hyperlog;

import android.support.annotation.NonNull;

import com.hypertrack.hyperlog.error.ErrorResponse;

/**
 * Created by Aman Jain on 18/09/17.
 */
public abstract class HyperLogCallback {

    /**
     * Called when a request succeeds.
     *
     * @param response The successful response containing the responseObject.
     */
    public abstract void onSuccess(@NonNull String response);

    /**
     * Called when a validation error occurs, request times out, or fails.
     *
     * @param errorResponse The request status.
     */
    public abstract void onError(@NonNull ErrorResponse errorResponse);

}
